# Fixation dot

The `fixation_dot` plug-in is a convenience plug-in. That is, it does nothing that could not be done using a `sketchpad` item, but is more convenient if you want to present only a central-fixation dot.

The following options are available:

- `Style` specifies the style of the fixation dot.
- `Duration` should be a positive integer value, 'keypress', or 'mouseclick', to wait respectively for a specified interval in milliseconds, until a key has been pressed, or until a mouse button has been clicked.
- `Foreground color` should be an English color name (e.g., 'blue') or an HTML color value (e.g., '#0000FF').
- `Background color` should be an English color name (e.g., 'blue') or an HTML color value (e.g., '#0000FF').
- The `X` and `Y` coordinates reflect the position of the fixation dot.
